@@ -25,6 +25,7 @@ import subprocess
 from glob import glob
 from time import sleep
 from shutil import copyfile, copytree, rmtree
+from datetime import datetime
 
 __all__ = ['Cassandra', 'skipIfNotInstalled', 'skipIfNotFound']
 
@@ -188,7 +189,7 @@ class Cassandra(object):
                 except Exception:
                     pass
 
-                if os.waitpid(pid, os.WNOHANG) != (0, 0):
+                if os.waitpid(pid, os.WNOHANG)[0] != 0:
                     raise RuntimeError("*** failed to launch cassandra ***\n" + self.read_log())
 
                 sleep(1)
@@ -217,8 +218,13 @@ class Cassandra(object):
 
         try:
             os.kill(self.pid, _signal)
-            while (os.waitpid(self.pid, 0)):
-                pass
+            killed_at = datetime.now()
+            while (os.waitpid(self.pid, os.WNOHANG)):
+                if (datetime.now() - killed_at).seconds > 10.0:
+                    os.kill(self.pid, signal.SIGKILL)
+                    raise RuntimeError("*** failed to shutdown cassandra (timeout) ***\n" + self.read_log())
+
+                sleep(0.1)
         except:
             pass
 
@@ -234,7 +240,7 @@ class Cassandra(object):
             return
 
         if self._use_tmpdir and os.path.exists(self.base_dir):
-            rmtree(self.base_dir)
+            rmtree(self.base_dir, ignore_errors=True)
 
     def read_log(self):
         try:
@@ -277,7 +283,7 @@ def skipIfNotInstalled(arg=None):
             except:
                 cond = True  # not found
 
-        return skipIf(cond, "Cassandra does not found")(fn)
+        return skipIf(cond, "Cassandra not found")(fn)
 
     if callable(arg):  # execute as simple decorator
         return decorator(arg, None)
